<?php

namespace Drupal\qbank_dam\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\qbank_dam\QBankDAMService;
use Exception;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class QBankDAMConfigForm.
 *
 * @package Drupal\qbank_dam\Form
 */
class QBankDAMConfigForm extends ConfigFormBase {

  protected $QAPI;

  public function __construct(QBankDAMService $qbank_api) {
    $this->QAPI = $qbank_api;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('qbank_dam.service'));
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'qbank_dam.qbankdamconfig',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'qbank_dam_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('qbank_dam.qbankdamconfig');

    if ($this->QAPI->checkStoredConfiguration()){
      $deploymentSites = $this->QAPI->getDeploymentSites();
    }
    else {
      $deploymentSites = [ 'No site' => $this->t('No site'), ];
    }

    $form['protocol'] = [
      '#type' => 'select',
      '#title' => $this->t('Protocol'),
      '#options' => ['HTTP' => $this->t('HTTP'), 'HTTPS' => $this->t('HTTPS')],
      '#size' => 2,
      '#default_value' => $config->get('protocol'),
    ];
    $form['api_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Url'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('api_url'),
    ];
    $form['client_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Client ID *'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('client_id'),
    ];
    $form['user'] = [
      '#type' => 'textfield',
      '#title' => $this->t('User'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('user'),
    ];
    $form['password'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Password'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('password'),
    ];
    $form['session_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Session ID'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('session_id'),
    ];
    $form['deployment_site'] = [
      '#type' => 'select',
      '#title' => $this->t('Deployment site'),
      '#options' => $deploymentSites,
      '#size' => 0,
      '#default_value' => $config->get('deployment_site'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);

    if ($this->QAPI->checkConfiguration(
        $form_state->getValue('api_url'),
        $form_state->getValue('client_id'),
        $form_state->getValue('user'),
        $form_state->getValue('password')
      ) == NULL) {
      $form_state->setErrorByName('missing qbank_url', $this->t('Unable to connect to QBank DAM API, please check your configuration'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('qbank_dam.qbankdamconfig')
      ->set('protocol', $form_state->getValue('protocol'))
      ->set('api_url', $form_state->getValue('api_url'))
      ->set('client_id', $form_state->getValue('client_id'))
      ->set('user', $form_state->getValue('user'))
      ->set('password', $form_state->getValue('password'))
      ->set('session_id', $form_state->getValue('session_id'))
      ->set('deployment_site', $form_state->getValue('deployment_site'))
      ->save();
  }

}
